@@ -37,11 +37,9 @@ for(i in 1:n.perm) {
   time.all <- rbind(time.all, c(time.ref, time.cor, time.omp))
 
   if(!all(res.ref == res.cor)) stop("ref != cor\n")   # When results differ, stop
-  if(!all(res.ref == res.omp)) stop("ref != mp\n")     # When results differ, stop
+  if(!all(res.ref == res.omp)) stop("ref != mp\n")    # When results differ, stop
 }
 
 boxplot(time.all)
 plot(time.all[,"ref"], time.all[,"cor"])
-t.test(time.all[,"ref"], time.all[,"cor"], paired = TRUE)
 plot(time.all[,"ref"], time.all[,"omp"])
-t.test(time.all[,"ref"], time.all[,"omp"], paired = TRUE)
